@@ -261,8 +261,13 @@ class ezfuc(object):
         """
         检查两个列表内容是否一致，与位置无关
         """
-        old_data = list(set(old_data))
-        new_data = list(set(new_data))
+        from functools import reduce
+        run_function = lambda x, y: x if y in x else x + [y]
+        old_data = reduce(run_function, [[], ] + old_data)
+        new_data = reduce(run_function, [[], ] + new_data)
+
+        # old_data = list(set(old_data))
+        # new_data = list(set(new_data))
         if len(old_data) != len(new_data):
             return False
         if isinstance(ezfuc.get_first(old_data), dict):
@@ -363,7 +368,7 @@ class ezfuc(object):
         print(f'\033[1;{color_code}m{st}\033[0m', end=end)
 
     @staticmethod
-    def save_excel(resList, excel_name, title=None, path=""):
+    def save_excel(resList, excel_name='data', title=None, path=""):
         """
         将列表数据保存到表格
         :param resList:
@@ -384,7 +389,10 @@ class ezfuc(object):
 
         l = 0
         if not isinstance(resList[-1], list):
-            resList = [list(i.values()) for i in resList]
+            try:
+                resList = [list(i.values()) for i in resList]
+            except AttributeError:
+                resList = [[i] for i in resList]
         if title:
             resList.insert(0, title)
         for line in tqdm(resList, ascii=True, desc=excel_name):
@@ -513,7 +521,7 @@ class EmailSend(object):
 @ezfuc.retry(2)
 def getIP():
     try:
-        res = requests.get("http://192.168.18.47:39111/123", timeout=3).json()
+        res = requests.get("http://192.168.18.8:39111/123", timeout=3).json()
     except:
         return None
 
